# Snapshot report for `test/js/deviceSpecificationTest.js`

The actual snapshot is saved in `deviceSpecificationTest.js.snap`.

Generated by [AVA](https://ava.li).

## structure

> Snapshot 1

    ServiceReply {
      deviceSpecification: DeviceSpecification {
        correspondingClientIdentifier: 'clientUuid',
        deviceType: '1',
        identifier: 'uuid',
        name: 'awesomeDeviceName',
        namespace: 'app',
      },
    }
